<TS language="lv_LV" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Izveidot jaunu adresi</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Jauns</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopēt iezīmēto adresi uz starpliktuvi</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopēt</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Izdzēst iezīmētās adreses no saraksta</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dzēst</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kop?t &amp;Nosaukumu</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redi??t</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Paroles dialogs</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Ierakstiet paroli</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Jauna parole</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Jaunā parole vēlreiz</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifr?t maci?u</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Lai veikto šo darb?bu, maci?š j?atsl?dz ar paroli.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Atsl?gt maci?u</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Main?t paroli</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Ierakstiet maci?a veco un jauno paroli.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Apstiprin?t maci?a šifr?šanu</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Maci?š nošifr?ts</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Maci?a šifr?šana neizdev?s</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Maci?a šifr?šana neizdev?s programmas k??das d??. J?su maci?š netika šifr?ts.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Ievad?t?s paroles nav vien?das.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Maci?u atšifr?t neizdev?s</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Maci?a atšifr?šanai ievad?t? parole nav pareiza.</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Maciņš</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pārskats</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Rādīt vispārēju maciņa pārskatu</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Sūtīt</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Saņemt</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Skatīt transakciju vēsturi</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Iziet</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Aizvērt programmu</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Iespējas...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Rādīt / Paslēpt</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Šifrēt &amp;maciņu...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Mainīt &amp;Paroli...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Mainīt maciņa šifrēšanas paroli</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Parakstīt &amp;ziņojumu...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Pārbaudīt ziņojumu...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Atkļūdošanas logs</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Atvērt atkļūdošanas un diagnostikas konsoli</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fails</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Uzstādījumi</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Palīdzība</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Sinhronizēts</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Sinhronizējos...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transakcija nosūtīta</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Ienākoša transakcija</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Maciņš ir &lt;b&gt;šifrēts&lt;/b&gt; un pašlaik &lt;b&gt;slēgts&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>T?kla br?din?jums</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Maksa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Pēc Maksas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Atlikums:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Daudzums</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Apstiprinājumi</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Apstiprināts</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kop?t adresi</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kop?t nosaukumu</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kop?t daudzumu</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Mainīt adrese</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Nosaukums</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adrese</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Jauna sa?emšanas adrese</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Jauna nos?t?šanas adrese</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Main?t sa?emšanas adresi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Main?t nos?t?šanas adresi</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Nupat ierakst?t? adrese "%1" jau atrodas adrešu gr?mat?.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nav iesp?jams atsl?gt maci?u.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Neizdev?s ?ener?t jaunu atsl?gu.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Iespējas</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Galvenais</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Tīkls</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Kartēt portu, izmantojot &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Ports:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Starpniekservera ports (piem. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Logu aizverot, minimiz?t, nevis beigt darbu. Kad š? izv?lne iesp?jota, programma aizv?rsies tikai p?c Beigt komandas izv?ln?.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Att?lot adreses transakciju sarakst?</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Logs</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Pēc loga minimizācijas rādīt tikai ikonu sistēmas teknē.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizēt uz sistēmas tekni, nevis rīkjoslu</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizēt aizverot</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Izskats</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Lietotāja interfeiss un &amp;valoda:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Vienības, kurās attēlot daudzumus:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Izvēlēties dalījuma vienību pēc noklusēšanas, ko izmantot interfeisā un nosūtot bitkoinus.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Labi</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Atcelt</translation>
    </message>
    <message>
        <source>default</source>
        <translation>pēc noklusēšanas</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Norādītā starpniekservera adrese nav derīga.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Pieejams:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Tava pašreizējā tērējamā bilance</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nenobriedušu:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Kopsumma:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Jūsu kopējā tekošā bilance</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Klienta versija</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informācija</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Sākuma laiks</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Savienojumu skaits</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Bloku virkne</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Pašreizējais bloku skaits</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Pēdējā bloka laiks</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Atvērt</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Notīrīt</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsole</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Tīkla Satiksme</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Kopsummas</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Ie.:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Iz.:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Atkļūdošanas žurnāla datne</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Notīrīt konsoli</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Bloku skaita nov?rt?jums</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Klienta v?rds</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Izmantojiet bultiņas uz augšu un leju, lai pārvietotos pa vēsturi, un &lt;b&gt;Ctrl-L&lt;/b&gt; ekrāna notīrīšanai.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Ierakstiet &lt;b&gt;help&lt;/b&gt; lai iegūtu pieejamo komandu sarakstu.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Sūtīt Bitkoinus</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Ieejas...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automātiski atlasīts</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nepietiekami līdzekļi!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Daudzums:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Maksa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Pēc Maksas:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Sūtīt vairākiem saņēmējiem uzreiz</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Pievienot Saņēmēju</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Notīrīt visu</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Apstiprināt nosūtīšanu</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Sūtīt</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kop?t daudzumu</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Apstiprin?t bitkoinu s?t?šanu</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Nos?t?majai summai j?b?t liel?kai par 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Daudzums p?rsniedz pieejamo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Kopsumma p?rsniedz pieejamo, ja pieskait?ta %1 transakcijas maksa.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Atrastas divas vien?das adreses, vien? nos?t?šanas reiz? uz katru adresi var s?t?t tikai vienreiz.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Apjo&amp;ms</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Saņēmējs:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Ziņojums:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Nosaukums:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>ielīmēt adresi no starpliktuves</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Lai pievienotu adresi adrešu gr?matai, tai j?dod nosaukums</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Paraksti - Parakstīt / Pabaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>Parakstīt &amp;Ziņojumu</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>ielīmēt adresi no starpliktuves</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Šeit ievadi ziņojumu kuru vēlies parakstīt</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopēt parakstu uz sistēmas starpliktuvi</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Parakstīt &amp;Ziņojumu</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Atiestatīt visus laukus</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Notīrīt visu</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Pārbaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Atiestatīt visus laukus</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Atv?rts l?dz %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/neapstiprin?tas</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 apstiprin?jumu</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, v?l nav veiksm?gi izzi?ots</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nav zin?ms</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Daudzums</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Transakcijas deta?as</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Šis panelis parāda transakcijas detaļas</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tips</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Daudzums</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Atv?rts l?dz %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Apstiprin?ts (%1 apstiprin?jumu)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>?ener?ts, ta?u nav akcept?ts</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Sa?emts ar</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Sa?emts no</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Nos?t?ts</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Maks?jums sev</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(nav pieejams)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transakcijas statuss. Turiet peli virs š? lauka, lai redz?tu apstiprin?jumu skaitu.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Transakcijas sa?emšanas datums un laiks.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Transakcijas tips.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Transakcijas m?r?a adrese.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Bilancei pievienotais vai at?emtais daudzums.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Šodien</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Šoned??</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Šom?nes</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>P?d?jais m?nesis</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Šogad</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Diapazons...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Sa?emts ar</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Nos?t?ts</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Sev</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Atrasts</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Cits</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minim?lais daudzums</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kop?t adresi</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kop?t nosaukumu</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kop?t daudzumu</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Main?t nosaukumu</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>R?d?t transakcijas deta?as</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Apstiprin?ts</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datums</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tips</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Daudzums</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Diapazons:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>uz</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Usage:</source>
        <translation>Lietojums:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Komandu saraksts</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Pal?dz?ba par komandu</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Izmantot opciju %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Konfigur?cijas fail? j?uzst?da rpcpassword=&lt;password&gt;:
%s
Ja fails neeksist?, izveidojiet to ar at?auju las?šanai tikai ?pašniekam.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Neder?gs daudzums priekš -paytxfree=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Nederīga -proxy adrese: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Nevar uzmekl?t -bind adresi: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Nevar atrisin?t -externalip adresi: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Nevar iel?d?t wallet.dat: maci?š boj?ts</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>K??da iel?d?jot wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Ielādē adreses...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Nevar pievienoties pie %s šaj? dator? (pievienošan?s atgrieza k??du %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Neder?gs daudzums</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>-onlynet komandā norādīts nepazīstams tīkls: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nepietiek bitkoinu</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ielādē bloku indeksu...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ielādē maciņu...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nevar ierakstīt adresi pēc noklusēšanas</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Skanēju no jauna...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ielāde pabeigta</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
</context>
</TS>